@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -79,9 +79,7 @@ mainly intended for prototyping:
 
 =cut
 
-# spot the odd one out - doesn't install currently, will add back in when
-# this is fixed. https://rt.cpan.org/Public/Bug/Display.html?id=101169
-# use Tickit::Console;
+use Tickit::Console;
 use Tickit::Widget::Border;
 use Tickit::Widget::Box;
 use Tickit::Widget::Breadcrumb;
@@ -89,6 +87,7 @@ use Tickit::Widget::Button;
 use Tickit::Widget::CheckButton;
 use Tickit::Widget::Decoration;
 use Tickit::Widget::Entry;
+use Tickit::Widget::Figlet;
 use Tickit::Widget::FileViewer;
 use Tickit::Widget::Frame;
 use Tickit::Widget::FloatBox;
@@ -148,6 +147,7 @@ our @EXPORT = our @EXPORT_OK = qw(
 	menubar submenu menuitem menuspacer
 	fileviewer
 	logpanel
+	figlet
 );
 
 =head1 METHODS
@@ -881,6 +881,29 @@ sub static {
 	apply_widget($w);
 }
 
+=head2 figlet
+
+Fancier text, generated by L<Text::FIGlet>. Same as static:
+
+ figlet 'some text';
+
+but you can specify a font as well:
+
+ figlet 'some text', font => 'slant';
+
+=cut
+
+sub figlet {
+	my %args = (text => @_);
+	$args{text} //= '';
+	my %parent_args = map {; $_ => delete $args{'parent:' . $_} } map /^parent:(.*)/ ? $1 : (), keys %args;
+	my $w = Tickit::Widget::Figlet->new(
+		%args
+	);
+	local @WIDGET_ARGS = (@WIDGET_ARGS, %parent_args);
+	apply_widget($w);
+}
+
 =head2 entry
 
 A L<Tickit::Widget::Entry> input field. Takes a coderef as the first parameter
